//
//  AudioDataDelegate.h
//  ZegoAvatar
//
//  Created by Azrael Long on 2022/2/14.
//

#pragma once

#import <Foundation/Foundation.h>

// 16 位的音频PCM数据格式
#define AUDIO_DATA_TYPE_INT16 0

// 8 位无符号的音频PCM数据格式, 字节顺序使用小端序
#define AUDIO_DATA_TYPE_UINT8 1

/** 音频采集回调代理, SDK在启动和停止采集的时候会回调这个协议*/
@protocol IAudioCapture<NSObject>

@optional
/** 开始采集*/
- (void)onStart;

/** 停止采集*/
- (void)onStop;

/**
 * 进行一些销毁工作, 例如 start 后的缓存等
 */
- (void) onDestroy;

@end

/** 音频采集的代理 */
@interface AudioDataDelegate : NSObject<IAudioCapture>

/** 填充声音数据, dataType 指示 buffer的数据类型,  0 : int16(short, 2byte), 1: unsigned byte(1byte) **/
- (void) sendAudioData: (void*) buffer size: (int) length dataType:(int) type  timeStamp:(long) timeStamp;

/**填充rtc 的声浪数据, 用于提升推理准确度*/
- (void) sendAudioLevelData: (float) level vad: (int) vad;

/**获取当前播放时间 ms*/
- (NSInteger) getDurationMs;


@end

