//
//  CameraProxy.h
//  ZegoAvatar
//
//  Created by Azrael Long on 29/9/2022.
//
#pragma once

#import <Foundation/Foundation.h>
#import <CoreVideo/CoreVideo.h>
#import "ZegoTypes.h"


@protocol IVideoCapture <NSObject>

@optional
/**
 * 接收到SDK启动摄像头的请求, 根据入参创建期望分辨率的采集器, 最终输出画面的分辨率可以不完全一致
 * @param width 期望采集的画面宽度
 * @param height 期望采集的画面高度
 */
- (void) onStart: (int) width height: (int)height;

/** 停止摄像头采集*/
- (void) onStop;

/**
 * 进行一些销毁工作, 例如 start 后的缓存等
 */
- (void) onDestroy;


@end

@interface VideoDataDelegate: NSObject<IVideoCapture>

/**
 * 发送图片数据给SDK, 格式支持 RGBA 和 BGRA, CPU数据建议尺寸不要太大, 建议 240*320左右.
 * 如果手机是横屏的, 需要注意传递正确的 rotation
 * @param buffer 图片数据
 */
-(void) sendImageBuffer:(CVPixelBufferRef) buffer param: (ZegoImageParam*) param;

@end

